::: beignet.datasets.AqSolDBSolubilityDataset
::: beignet.datasets.AstraZenecaLipophilicityDataset
::: beignet.datasets.BroccatelliPGlycoproteinInhibitionDataset
::: beignet.datasets.HouHumanIntestinalAbsorptionDataset
::: beignet.datasets.MaBioavailabilityDataset
::: beignet.datasets.NCATSPAMPAPermeabilityDataset
::: beignet.datasets.WangEffectivePermeabilityDataset
